<p align="center">
  <a href="http://mariadb.com/">
    <img src="https://mariadb.com/kb/static/images/logo-2018-black.png">
  </a>
</p>

# MariaDB Connector/Python

[![License (LGPL version 2.1)][licence-image]][licence-url]
[![Python 3.6][python-image]][python-url]
[![Build Status](https://travis-ci.com/mariadb-corporation/mariadb-connector-python.svg?branch=master)](https://travis-ci.com/mariadb-corporation/mariadb-connector-python)
<a href="https://scan.coverity.com/projects/mariadb-connector-python">
  <img alt="Coverity Scan Build Status"
       src="https://scan.coverity.com/projects/21386/badge.svg"/>
</a>

MariaDB Connector/Python enables python programs to access MariaDB and MySQL databases, using an API
which is compliant with the Python DB API 2.0 (PEP-249). It is written in C and uses MariaDB Connector/C
client library for client server communication.

## License

MariaDB Connector/Python is licensed under the LGPL 2.1

## Source code

MariaDB Connector/Python source code is hosted on [Github](https://github.com/mariadb-corporation/mariadb-connector-python)

## Documentation

MariaDB Connector/Python documentation can be found on [Github Pages](https://mariadb-corporation.github.io/mariadb-connector-python/)

## Bugs

Bugs and feature requests should be filed in the [MariaDB bug ticket system](https://jira.mariadb.org/)


[licence-image]:https://img.shields.io/badge/license-GNU%20LGPL%20version%202.1-green.svg?style=flat-square
[licence-url]:http://opensource.org/licenses/LGPL-2.1
[python-image]:https://img.shields.io/badge/python-3.6-blue.svg
[python-url]:https://www.python.org/downloads/release/python-360/
